"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tryDecryptOpenPgp = void 0;
const tslib_1 = require("tslib");
const openpgp = tslib_1.__importStar(require("openpgp"));
const logger_1 = require("../../logger");
const regex_1 = require("../../util/regex");
async function tryDecryptOpenPgp(privateKey, encryptedStr) {
    if (encryptedStr.length < 500) {
        // optimization during transition of public key -> pgp
        return null;
    }
    try {
        const pk = await openpgp.readPrivateKey({
            // prettier-ignore
            armoredKey: privateKey.replace((0, regex_1.regEx)(/\n[ \t]+/g), '\n'), // little massage to help a common problem
        });
        const startBlock = '-----BEGIN PGP MESSAGE-----\n\n';
        const endBlock = '\n-----END PGP MESSAGE-----';
        let armoredMessage = encryptedStr.trim();
        if (!armoredMessage.startsWith(startBlock)) {
            armoredMessage = `${startBlock}${armoredMessage}`;
        }
        if (!armoredMessage.endsWith(endBlock)) {
            armoredMessage = `${armoredMessage}${endBlock}`;
        }
        const message = await openpgp.readMessage({
            armoredMessage,
        });
        const { data } = await openpgp.decrypt({
            message,
            decryptionKeys: pk,
        });
        logger_1.logger.debug('Decrypted config using openpgp');
        return data;
    }
    catch (err) {
        logger_1.logger.debug({ err }, 'Could not decrypt using openpgp');
        return null;
    }
}
exports.tryDecryptOpenPgp = tryDecryptOpenPgp;
//# sourceMappingURL=openpgp.js.map